"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStorageMetrics = void 0;
const prom_client_1 = require("prom-client");
function createStorageMetrics(storageRegistry = new prom_client_1.Registry()) {
    return {
        registry: storageRegistry,
        metrics: {
            activeGauge: new prom_client_1.Gauge({
                name: `active_workflows`,
                help: "Total number of active jobs (currently being processed)",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            delayedGauge: new prom_client_1.Gauge({
                name: `delayed_workflows`,
                help: "Total number of jobs that will run in the future",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            waitingGauge: new prom_client_1.Gauge({
                name: `waiting_workflows`,
                help: "Total number of jobs waiting to be processed",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            failedGauge: new prom_client_1.Gauge({
                name: `failed_workflows`,
                help: "Total number of jobs currently in a failed state",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            completedCounter: new prom_client_1.Counter({
                name: `completed_workflows_total`,
                help: "Total number of completed jobs",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            failedRunsCounter: new prom_client_1.Counter({
                name: `failed_workflow_runs_total`,
                help: "Total number of failed job runs",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            failedWithMaxRetriesCounter: new prom_client_1.Counter({
                name: `failed_with_max_retries_workflows_total`,
                help: "Total number of jobs that failed after max retries. Eg: they will require manual intervention to succeed",
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            processedDuration: new prom_client_1.Histogram({
                name: `worklow_processing_duration`,
                help: "Processing time in ms for completed jobs (processing until completed)",
                buckets: [6000, 7000, 7500, 8000, 8500, 9000, 10000, 12000],
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
            completedDuration: new prom_client_1.Histogram({
                name: `workflow_total_duration`,
                help: "Completion time in ms for jobs (created until completed)",
                buckets: [
                    7500, 10000, 20000, 30000, 45000, 60000, 90000, 120000, 240000,
                ],
                labelNames: ["queue"],
                registers: [storageRegistry],
            }),
        },
    };
}
exports.createStorageMetrics = createStorageMetrics;
//# sourceMappingURL=storage.metrics.js.map